PyXMake Developer Guide: PyXMake.VTL.stm_make.pytest_pyxmake Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Attributes | Protected Member Functions | Static Protected Attributes | List of all members
PyXMake.VTL.stm_make.pytest_pyxmake Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.pytest_pyxmake:

## Public Attributes
self.source_path | source_path = Utility.GetPyXMakePath()
list | include
Public Attributes inherited from PyXMake.VTL.stm_make.pyx_pytest
int | verbose = 0
str | source_path = ''
| output_file_path = os.getcwd()
| scratch_path = os.getcwd()
| include = None
Public Attributes inherited from PyXMake.VTL.stm_make._BaseTest
str | command = "py.test"
| out = None
| covout = None
| verbose = self.distribution.verbose
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose

## Protected Member Functions
| _create_command (self)
Protected Member Functions inherited from PyXMake.VTL.stm_make.pyx_pytest
| _run_command (self, command)
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _perform_post_actions (self)

## Static Protected Attributes
str | _PACKAGE_NAME = 'PyXMake'
Static Protected Attributes inherited from PyXMake.VTL.stm_make.pyx_pytest
str | _PACKAGE_NAME = ''

## Additional Inherited Members
Public Member Functions inherited from PyXMake.VTL.stm_make.pyx_pytest
| initialize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseTest
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)
Static Public Attributes inherited from PyXMake.VTL.stm_make.pyx_pytest
str | description = "Run predefined unit tests using Pytest."
list | user_options
Static Public Attributes inherited from PyXMake.VTL.stm_make._BaseTest
str | description = "Runs all unit tests using py.test."
list | user_options
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()

## Detailed Description

    Runs the test command for PyXMake using PyTest.

Definition at line 1041 of file stm_make.py.

## Member Function Documentation

## ◆ _create_command()

PyXMake.VTL.stm_make.pytest_pyxmake._create_command | ( |  | self | ) |
| protected

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 1047 of file stm_make.py.

## Member Data Documentation

## ◆ _PACKAGE_NAME

str PyXMake.VTL.stm_make.pytest_pyxmake._PACKAGE_NAME = 'PyXMake'
| staticprotected

Definition at line 1045 of file stm_make.py.

## ◆ include

list PyXMake.VTL.stm_make.pytest_pyxmake.include

Initial value:
= [ os.path.join(self.source_path,"VTL","examples",'pyx_gfortran.py'),
os.path.join(self.source_path,"VTL","examples",'pyx_py2x.py'),
os.path.join(self.source_path,"VTL","examples",'pyx_doxygen.py'),
os.path.join(self.source_path,"VTL","examples",'pyx_openapi.py'),
os.path.join(self.source_path,"VTL","examples",'pyx_pyreq.py') ]

Definition at line 1051 of file stm_make.py.

## ◆ source_path

self.source_path PyXMake.VTL.stm_make.pytest_pyxmake.source_path = Utility.GetPyXMakePath()

Definition at line 1050 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py